<template>
  <div class="bbsl-common-page">
    <div :class="['bbsl-table-search', isAdvanced ? 'advanced-search' : '']">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="5">
          <el-col :span="5">
            <el-form-item label="方案名称">
              <el-input clearable placeholder="请输入方案名称" v-model="querys[3].value" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="活动考评人">
              <el-select clearable filterable style="width:100%" v-model="querys[0].value" placeholder="请选择活动考评人">
                <el-option v-for="item in checkUserData" :key="item.id" :label="item.fullname"
                  :value="item.id"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="培训类型">
              <el-select clearable filterable style="width:100%" v-model="querys[1].value" placeholder="请选择培训类型">
                <el-option v-for="item in trainingType2Data" :key="item.value" :label="item.name"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="培训对象">
              <el-select clearable filterable style="width:100%" v-model="querys[2].value" placeholder="请选择培训对象">
                <el-option v-for="item in pxdxData" :key="item.value" :label="item.name"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button size="small" type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button size="small" icon="el-icon-refresh" @click="handleReset">重置</el-button>
            <el-link :underline="false" type="primary" @click="advanced">
              {{ isAdvanced ? '基础搜索' : '高级搜索' }}
            </el-link>
          </el-col>
        </el-row>
        <el-row :gutter="5">
          <el-col :span="7">
            <el-form-item label="开始时间">
              <el-date-picker v-model="querys[4].value" clearable type="daterange" range-separator="至"
                start-placeholder="开始日期" end-placeholder="结束日期" value-format="yyyy-MM-dd"></el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="培训周期">
              <el-select clearable filterable style="width:100%" v-model="querys[0].value" placeholder="请选择培训周期">
                <el-option v-for="item in trainingCycleData" :key="item.value" :label="item.name"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div :class="['bbsl-table-content', isAdvanced ? 'advanced-search-table' : '']" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column min-width="100" fixed prop="planName" label="方案名称" show-overflow-tooltip></el-table-column>
        <!-- <el-table-column
          min-width="100"
          fixed
          prop="trainingType2"
          label="培训类型"
          show-overflow-tooltip
        ></el-table-column> -->
        <el-table-column fixed prop="pxdx" label="培训对象" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="trainingCycle" label="培训周期" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="trainingPurpost" label="工作目的描述" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="location" label="活动地点" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="participant" label="参加人员描述" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="sponsor" label="活动主办方" show-overflow-tooltip></el-table-column>
        <el-table-column fixed sortable prop="trainingStartDate" label="活动开始时间" show-overflow-tooltip></el-table-column>
        <el-table-column fixed sortable prop="trainingEndDate" label="活动结束时间" show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <CmgtSaftyTrainingPlanFormDialog ref="formModal"></CmgtSaftyTrainingPlanFormDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import CmgtSaftyTrainingPlanApi from '@/views/Manage/saftyTraining/api/CmgtSaftyTrainingPlanApi'
import CmgtSaftyTrainingPlanFormDialog from '@/views/Manage/saftyTraining/components/CmgtSaftyTrainingPlanFormDialog'

export default {
  name: 'CmgtSaftyTrainingPlanManage',
  components: {
    CmgtSaftyTrainingPlanFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      checkUserData: [],
      url: {
        delete: '/manager/cmgtSaftyTrainingPlan/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'training_cycle_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'training_type_2',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'pxdx_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'plan_name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'training_start_date_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: [],
      isShow: false
    }
  },
  created() {
    this.pxdxData = dictContracts.getDictItemsFromCache('pxdx')
    this.trainingType2Data = dictContracts.getDictItemsFromCache('pxlx')
    this.trainingCycleData = dictContracts.getDictItemsFromCache('pxzq')
  },
  mounted() { },
  methods: {
    checkUserList() {
      CmgtSaftyTrainingPlanApi.getAllUser(res => {
        // console.log(res)
        this.checkUserData = res
        this.tableData.forEach(item => {
          this.pxdxData.forEach(val => {
            if (item.pxdx == val.value) {
              item.pxdx = val.name
            }
          })
          this.trainingType2Data.forEach(val => {
            if (item.trainingType2 == val.value) {
              item.trainingType2 = val.name
            }
          })
          this.trainingCycleData.forEach(val => {
            if (item.trainingCycle == val.value) {
              item.trainingCycle = val.name
            }
          })
        })
      })
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
      this.querys[4].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      if (this.querys[4].value) {
        this.queryParam.querys.push(this.querys[4])
      }
      CmgtSaftyTrainingPlanApi.loadCmgtSaftyTrainingPlan(
        this.queryParam,
        res => {
          console.log(res, 'res')
          this.total = res.total
          this.tableData = res.rows
          this.checkUserList()
          this.$set(this.tableData)
          this.loading = false
        }
      )
    },
    handleDelete() {
      //   console.log(this.multipleSelection)
      CmgtSaftyTrainingPlanApi.deleteCmgtSaftyTrainingPlan(
        this.multipleSelection
      )
        .then(res => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '删除成功',
              duration: 2000
            })
            this.queryParam.pageBean.page = 1
            this.loadData()
          }
        })
        .catch(res => {
          this.$notify({
            type: 'error',
            message: res.message,
            duration: 2000,
            offset: 80
          })
        })
    },
    // 修改
    handleUpdate(row) {
      // console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
